@@ -60,7 +60,7 @@ function search_on_loginnt($login) {
     $f2_name = $_SESSION['OCS']['config']['LDAP_CHECK_FIELD2_NAME'];
 
     // default attributes for query
-    $attributs = array("dn", "cn", "givenname", "sn", "mail", "title");
+    $attributs = array("dn", "cn", "givenname", "sn", "mail", "title", "memberof");
 
     // search for the custom user level attributes if they're defined
     if ($f1_name != '') {
@@ -86,23 +86,19 @@ function search_on_loginnt($login) {
     $_SESSION['OCS']['details']['mail'] = $info[0]['mail'][0];
     $_SESSION['OCS']['details']['title'] = $info[0]['title'][0];
 
-    // if the extra attributes are there, save them as well
-    if ($info[0][$f1_name][0] != '') {
-
-        if ($f1_name == "memberof") {    
-            $_SESSION['OCS']['details'][$f1_name] = $info[0][strtolower($f1_name)];
-        } else {
-            $_SESSION['OCS']['details'][$f1_name] = $info[0][strtolower($f1_name)][0];
-        }
+    if (strtolower($f1_name) == "memberof") {    
+        $_SESSION['OCS']['details'][$f1_name] = $info[0][strtolower($f1_name)];
+    } else {
+        $_SESSION['OCS']['details'][$f1_name] = $info[0][strtolower($f1_name)][0];
     }
+    
 
-    if ($info[0][strtolower($f2_name)][0] != '') {
-        if ($f2_name == "memberof") {
-            $_SESSION['OCS']['details'][$f2_name] = $info[0][strtolower($f2_name)];
-        } else {
-            $_SESSION['OCS']['details'][$f2_name] = $info[0][strtolower($f2_name)][0];
-        }
+    if (strtolower($f2_name) == "memberof") {
+        $_SESSION['OCS']['details'][$f2_name] = $info[0][strtolower($f2_name)];
+    } else {
+        $_SESSION['OCS']['details'][$f2_name] = $info[0][strtolower($f2_name)][0];
     }
+    
     return $info;
 }
 
