@@ -232,9 +232,12 @@ if ($protectedPost['onglet'] == 'NEW') {
             $querydico .= ' count(NAME) as ' . $value . ',';
         }
     }
+
     $querydico = substr($querydico, 0, -1);
     $querydico .= " from software_name
-			where name in (" . $list_soft . ") and name != ''
+            where name != ''
+            and name not in (select extracted name from dico_soft)
+            and name not in (select extracted name from dico_ignored)
 			group by name ";
 }
 /* * *****************************************************CAS OF IGNORED****************************************************** */
