@@ -171,12 +171,16 @@ function find_all_account_tab($tab_value, $onlyactiv = '', $first = '') {
     return $array_tab_account;
 }
 
-function find_value_field($name) {
+function find_value_field($name, $type = null) {
     $array_tab_account = array();
     $data = look_config_default_values($name . '\_%', true);
     if (isset($data['name'])) {
         foreach ($data['name'] as $field => $value) {
+          if($type == '5'){
             $array_tab_account[$data['tvalue'][$field]] = $data['tvalue'][$field];
+          }else{
+            $array_tab_account[$data['ivalue'][$field]] = $data['tvalue'][$field];
+          }
         }
     }
     return $array_tab_account;
@@ -373,7 +377,7 @@ function admininfo_computer($id = "") {
         $sql_account_data .= " LIMIT 1 ";
     }
 
-    $res_account_data = mysql2_query_secure($sql_account_data, $_SESSION['OCS']["readServer"], $arg_account_data);
+    $res_account_data = mysql2_query_secure($sql_account_data, $_SESSION['OCS']["writeServer"], $arg_account_data);
     $val_account_data = mysqli_fetch_array($res_account_data);
     if (is_array($val_account_data)) {
         return $val_account_data;
@@ -419,7 +423,7 @@ function updateinfo_computer($id, $values, $list = '') {
     }
 
     array_push($arg_account_data, $id);
-    mysql2_query_secure($sql_account_data, $_SESSION['OCS']["readServer"], $arg_account_data);
+    mysql2_query_secure($sql_account_data, $_SESSION['OCS']["writeServer"], $arg_account_data);
     return $l->g(1121);
 }
 
