@@ -61,6 +61,7 @@ function look_config_default_values($field_name, $like = '', $default_values = '
 /* * ****************************************************SQL FUNCTION*************************************************** */
 
 function generate_secure_sql($sql, $arg = '') {
+
     if (is_array($arg)) {
         foreach ($arg as $value) {
             $arg_array_escape_string[] = mysqli_real_escape_string($_SESSION['OCS']["readServer"], $value);
@@ -152,29 +153,63 @@ function prepare_sql_tab($list_fields, $explu = array(), $distinct = false) {
     return array('SQL' => substr($begin_sql, 0, -2) . " ", 'ARG' => $begin_arg);
 }
 
-function dbconnect($server, $compte_base, $pswd_base, $db = DB_NAME) {
+function dbconnect($server, $compte_base, $pswd_base, $db = DB_NAME, $sslkey = SSL_KEY, $sslcert = SSL_CERT, $cacert = CA_CERT, $port = 3306, $sslmode = SSL_MODE, $enablessl = ENABLE_SSL) {
     error_reporting(E_ALL & ~E_NOTICE);
     mysqli_report(MYSQLI_REPORT_STRICT);
     //$link is ok?
     try {
-        $link = mysqli_connect($server, $compte_base, $pswd_base);
+        $dbc = mysqli_init();
+        if($enablessl == "1") {
+            $dbc->options(MYSQLI_OPT_SSL_VERIFY_SERVER_CERT, true);
+            $dbc->ssl_set($sslkey, $sslcert, $cacert, NULL, NULL);
+            if($sslmode == "MYSQLI_CLIENT_SSL") {
+                $connect = MYSQLI_CLIENT_SSL;
+            } elseif($sslmode == "MYSQLI_CLIENT_SSL_DONT_VERIFY_SERVER_CERT") {
+                $connect = MYSQLI_CLIENT_SSL_DONT_VERIFY_SERVER_CERT;
+            }
+        } else {
+            $connect = NULL;
+        }
+
+        $dbc->options(MYSQLI_INIT_COMMAND, "SET NAMES 'utf8'");
+        $dbc->options(MYSQLI_INIT_COMMAND, "SET sql_mode='NO_ENGINE_SUBSTITUTION'");
+
+        $link = mysqli_real_connect($dbc, $server, $compte_base, $pswd_base, NULL, $port, NULL, $connect);
+
+        if($link) {
+            $link = $dbc;
+        }
     } catch (Exception $e) {
         if (mysqli_connect_errno()) {
             return "ERROR: MySql connection problem " . $e->getCode() . "<br>" . $e->getMessage();
         }
     }
     //database is ok?
-    if (!mysqli_select_db($link, $db)) {
+    if (!$link->select_db($db)) {
         return "NO_DATABASE";
     }
-    //force UTF-8
-    mysqli_query($link, "SET NAMES 'utf8'");
-    //sql_mode => not strict
-    mysqli_query($link, "SET sql_mode='NO_AUTO_CREATE_USER,NO_ENGINE_SUBSTITUTION'");
 
     return $link;
 }
 
+// Function to retrieve the columns that are full-text indexed within a table
+// Arguments:
+//   $tableName : The name of the SQL table to query
+//   $tableAlias: The alias of the SQL table in the query
+function dbGetFTIndex($tableName, $tableAlias) {
+
+     $ft_idx = [];
+     $sql_ft='show index from ' . $tableName . ';';
+     $resultDetails = mysql2_query_secure($sql_ft, $_SESSION['OCS']["readServer"]);
+     while($row = mysqli_fetch_object($resultDetails)){
+           if ( $row->Index_type == 'FULLTEXT') {
+                $ft_idx[ $row->Column_name ] = "$tableAlias.$row->Column_name";
+           }
+     }
+
+     return $ft_idx;
+}
+
 /* * *********************************END SQL FUNCTION***************************************** */
 
 function addLog($type, $value = "", $lbl_sql = '') {
@@ -196,12 +231,8 @@ function addLog($type, $value = "", $lbl_sql = '') {
 
 function dateTimeFromMysql($v) {
     global $l;
-
-    $sql = "SELECT date_format('%s', '%s %%H:%%i:%%S') as dt";
-    $arg = array($v, $l->g(269));
-    $result = mysql2_query_secure($sql, $_SESSION['OCS']["readServer"], $arg);
-    $ret = mysqli_fetch_array($result);
-    return $ret['dt'];
+    $d = DateTime::createFromFormat('Y-m-d H:i:s', $v);
+    return $d? $d->format($l->g(1242)) : '';
 }
 
 function reloadform_closeme($form = '', $close = false) {
@@ -334,7 +365,6 @@ function html_header($noJavascript = false) {
 				<link rel="stylesheet" href="libraries/bootstrap/css/bootstrap.min.css">
 				<link rel="stylesheet" href="libraries/bootstrap/css/bootstrap-theme.min.css">
 				<link rel="stylesheet" href="libraries/select2/css/select2.min.css" />
-				<link rel="stylesheet" href="themes/'.$value_theme['tvalue']['CUSTOM_THEME'].'/style.css">
 				<link rel="stylesheet" href="css/dataTables-custom.css">
 				<link rel="stylesheet" href="libraries/datatable/media/css/dataTables.bootstrap.css">
 				<link rel="stylesheet" href="css/ocsreports.css">
@@ -342,7 +372,8 @@ function html_header($noJavascript = false) {
 				<link rel="stylesheet" href="css/header.css">
 				<link rel="stylesheet" href="css/computer_details.css">
         <link rel="stylesheet" href="css/bootstrap-formhelpers.css">
-				<link rel="stylesheet" href="css/forms.css">';
+				<link rel="stylesheet" href="css/forms.css">
+				<link rel="stylesheet" href="themes/'.$value_theme['tvalue']['CUSTOM_THEME'].'/style.css">';
 
     if (!$noJavascript) {
         //js for graph
@@ -382,7 +413,13 @@ function strip_tags_array($value = '') {
         $value = "Objet de la classe " . $value;
         return $value;
     }
+
     $value = is_array($value) ? array_map('strip_tags_array', $value) : strip_tags($value, "<p><b><i><font><br><center>");
+
+    if(!is_array($value)){
+      $value = htmlspecialchars($value, ENT_QUOTES);
+    }
+
     return $value;
 }
 
@@ -443,9 +480,12 @@ function formGroup($inputType, $inputName, $name, $size, $maxlength, $inputValue
 			echo "<option value='".$option."' ".($inputValue == $option ? 'selected' : '').">".($arrayDisplayValues[$option] ? $arrayDisplayValues[$option] : $option)."</option>";
 		}
 		echo "</select>";
-	}
-	else{
-		echo "<input type='".$inputType."' name='".$inputName."' id='".$inputName."' size='".$size."' maxlength='".$maxlength."' value='".$inputValue."' class='form-control ".$class."' ".$attrBalise.">";
+	} else {
+        if($inputType == "checkbox") {
+            echo "<input type='".$inputType."' name='".$inputName."' id='".$inputName."' size='".$size."' maxlength='".$maxlength."' value='".$inputValue."' class='".$class."' ".$attrBalise.">";
+        } else {
+            echo "<input type='".$inputType."' name='".$inputName."' id='".$inputName."' size='".$size."' maxlength='".$maxlength."' value='".$inputValue."' class='form-control ".$class."' ".$attrBalise.">";
+        }
   }
   if($groupAddon != ""){
   	echo "<span class='input-group-addon' id='".$name."-addon'>".$groupAddon."</span>";
@@ -474,7 +514,7 @@ function calendars($NameInputField,$DateFormat)
 
 
 
-function modif_values($field_labels, $fields, $hidden_fields, $options = array()) {
+function modif_values($field_labels, $fields, $hidden_fields, $options = array(), $field_name="form-group") {
 	global $l;
 
 	$options = array_merge(array(
@@ -496,6 +536,12 @@ function modif_values($field_labels, $fields, $hidden_fields, $options = array()
 
                     $field = $fields[$key];
 
+                    if (is_array($field_name)){
+                        $name = $field_name[$key];
+                    } else {
+                        $name = $field_name;
+                    }
+
                     /**
                      * 0 = text
                      * 1 = textarea
@@ -512,6 +558,7 @@ function modif_values($field_labels, $fields, $hidden_fields, $options = array()
                      * 12 = QRCode
                      * 13 = Disabled
                      * 14 = Date
+                     * 15 = number
                      **/
                     if($field['INPUT_TYPE'] == 0 ||
                             $field['INPUT_TYPE'] == 1 ||
@@ -538,14 +585,17 @@ function modif_values($field_labels, $fields, $hidden_fields, $options = array()
                         $inputType = 'qrcode';
                     } elseif($field['INPUT_TYPE'] == 11){
                         $inputType = 'radio';
+                    } elseif($field['INPUT_TYPE'] == 15){
+                        $inputType = 'number';
                     } else {
                             $inputType = 'hidden';
                     }
 
-                    echo "<div class='form-group'>";
+                    echo "<div class='$name'>";
                         echo "<label for='".$field['INPUT_NAME']."' class='col-sm-2 control-label'>".$label."</label>";
                         echo "<div class='col-sm-10'>";
 
+                                $field_checkbox = array();
                                 if($inputType == 'text'){
                                     if($field['INPUT_TYPE'] == 14){
                                         echo "<div class='input-group date form_datetime'>";
@@ -556,6 +606,12 @@ function modif_values($field_labels, $fields, $hidden_fields, $options = array()
                                     if($field['COMMENT_AFTER'] == ""){
                                       echo "</div>";
                                     }
+                                }else if($inputType == 'number'){
+                                    echo "<div class='input-group'>";
+                                    echo "<input type='".$inputType."' name='".$field['INPUT_NAME']."' id='".$field['INPUT_NAME']."' value='".$field['DEFAULT_VALUE']."' min='1' class='form-control' ".$field['CONFIG']['JAVASCRIPT'].">";
+                                    if($field['COMMENT_AFTER'] == ""){
+                                      echo "</div>";
+                                    }
                                 }else if($inputType == 'disabled'){
                                     echo "<div class='input-group'>";
                                     echo "<input type='text' name='".$field['INPUT_NAME']."' id='".$field['INPUT_NAME']."' value='".$field['DEFAULT_VALUE']."' class='form-control' ".$field['CONFIG']['JAVASCRIPT']." readonly>";
@@ -586,28 +642,36 @@ function modif_values($field_labels, $fields, $hidden_fields, $options = array()
                                         }
                                       }
                                   }
+                                  echo "<div>";
                                   foreach ($field['DEFAULT_VALUE'] as $key => $value){
-                                    if(array_key_exists($value, $field_checkbox)){
-                                        echo "<div><input style='display:initial;width:20px;height: 14px;'  type='".$inputType."' name='".$field['INPUT_NAME']."_".$value."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT']." checked> $value </div> ";
-                                    }else{
-                                        echo "<div><input style='display:initial;width:20px;height: 14px;' type='".$inputType."' name='".$field['INPUT_NAME']."_".$value."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT'].">$value </div>";
-                                    }
+                                      if(array_key_exists($value, $field_checkbox)){
+                                          echo "<div><input style='display:initial;width:20px;height: 14px;'  type='".$inputType."' name='".$field['INPUT_NAME']."_".$value."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT']." checked> $value </div> ";
+                                      }else{
+                                          echo "<div><input style='display:initial;width:20px;height: 14px;' type='".$inputType."' name='".$field['INPUT_NAME']."_".$value."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT']."> $value </div>";
+                                      }
+                                  }
+                                  if($field['COMMENT_AFTER'] == ""){
+                                    echo "</div>";
                                   }
                                 } else if($inputType == 'radio'){
                                   if($field["CONFIG"]["SELECTED_VALUE"] != ''){
                                       $field_radio = explode("&&&", $field["CONFIG"]["SELECTED_VALUE"]);
                                       foreach($field_radio as $keys => $values){
-                                        if($values != ''){
-                                          $field_radio[$values] = $values;
-                                        }
+                                          if($values != ''){
+                                            $field_radio[$values] = $values;
+                                          }
                                       }
                                   }
+                                  echo "<div>";
                                   foreach ($field['DEFAULT_VALUE'] as $key => $value){
-                                    if(array_key_exists($value, $field_radio)){
-                                        echo "<div><input style='display:initial;width:20px;height: 14px;'  type='".$inputType."' name='".$field['INPUT_NAME']."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT']." checked> $value </div> ";
-                                    }else{
-                                        echo "<div><input style='display:initial;width:20px;height: 14px;' type='".$inputType."' name='".$field['INPUT_NAME']."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT'].">$value </div>";
-                                    }
+                                      if(array_key_exists($key, $field_radio)){
+                                          echo "<div><input style='display:initial;width:20px;height: 14px;'  type='".$inputType."' name='".$field['INPUT_NAME']."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT']." checked> $value </div> ";
+                                      }else{
+                                          echo "<div><input style='display:initial;width:20px;height: 14px;' type='".$inputType."' name='".$field['INPUT_NAME']."' value='".$key."' id='".$field['INPUT_NAME']."_".$value."' class='form-control' ".$field['CONFIG']['JAVASCRIPT'].">$value </div>";
+                                      }
+                                  }
+                                  if($field['COMMENT_AFTER'] == ""){
+                                    echo "</div>";
                                   }
                                 } else if( $inputType == 'button' || $inputType == 'link'){
                                     echo "<a href='".$field['DEFAULT_VALUE']."' class='".($inputType == 'button') ? 'btn' : ''."' ".$field['CONFIG']['JAVASCRIPT']."></a>";
@@ -621,7 +685,6 @@ function modif_values($field_labels, $fields, $hidden_fields, $options = array()
                                     echo "<span class='input-group-addon' id='".$field['INPUT_NAME']."-addon'>".$field['COMMENT_AFTER']."</span>";
                                     echo "</div>";
                                 }
-
                         echo "</div>";
                     echo "</div>";
 
@@ -715,7 +778,7 @@ function check_requirements(){
         $msg_lbl['error'][] = $l->g(2035);
     }
     //msg= no mysqli_connect function
-    if (!function_exists('mysqli_connect')) {
+    if (!function_exists('mysqli_real_connect')) {
         $msg_lbl['error'][] = $l->g(2037);
     }
     if ((file_exists(CONF_MYSQL) && !is_writable(CONF_MYSQL)) || (!file_exists(CONF_MYSQL) && !is_writable(CONF_MYSQL_DIR))) {
@@ -725,9 +788,6 @@ function check_requirements(){
     if (version_compare(phpversion(), '5.4', '<')) {
         $msg_lbl['warning'][] = $l->g(2113) . " " . phpversion() . " ) ";
     }
-    if (!class_exists('SoapClient')) {
-        $msg_lbl['warning'][] = $l->g(6006);
-    }
     if (!function_exists('xml_parser_create')) {
         $msg_lbl['warning'][] = $l->g(2036);
     }
@@ -780,7 +840,7 @@ function check_requirements(){
  */
 function return_bytes($val) {
     $val = trim($val);
-    $last = strtolower($val{strlen($val) - 1});
+    $last = strtolower($val[strlen($val) - 1]);
     switch ($last) {
         case 'g':
             $val *= 1024;
