@@ -1677,14 +1677,20 @@ function ajaxgestionresults($resultDetails,$list_fields,$tab_options){
 						break;
 					case "SUP":
 						if ( $value_of_field!= '&nbsp;'){
-							if (isset($tab_options['LBL_POPUP'][$key])){
-								if (isset($row[$tab_options['LBL_POPUP'][$key]]))
+							if (isset($tab_options['LBL_POPUP'][$key])) {
+								if (isset($row[$tab_options['LBL_POPUP'][$key]])) {
 									$lbl_msg=$l->g(640)." ".$row_temp[$tab_options['LBL_POPUP'][$key]];
-								else
+								} else {
 									$lbl_msg=$tab_options['LBL_POPUP'][$key];
-							}else
+								}
+							} else {
 								$lbl_msg=$l->g(640)." ".$value_of_field;
-							$row[$key]="<a href=# OnClick='confirme(\"\",\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"".$form_name."\",\"SUP_PROF\",\"".htmlspecialchars($lbl_msg, ENT_QUOTES)."\");'><span class='glyphicon glyphicon-remove'></span></a>";
+							}
+							if($form_name == "admins" && $_SESSION['OCS']["loggeduser"] == htmlspecialchars($value_of_field, ENT_QUOTES)) {
+								// Do nothing 
+							} else {
+								$row[$key]="<a href=# OnClick='confirme(\"\",\"".htmlspecialchars($value_of_field, ENT_QUOTES)."\",\"".$form_name."\",\"SUP_PROF\",\"".htmlspecialchars($lbl_msg, ENT_QUOTES)."\");'><span class='glyphicon glyphicon-remove'></span></a>";
+							}	
 						}
 						break;
 					case "NAME":
