@@ -1,15 +1,14 @@
 #!/usr/bin/php
-
 <?php
-require_once('../dbconfig.inc.php');
 require_once('../var.php');
+require_once(CONF_MYSQL);
 require_once('../require/function_commun.php');
 require_once('../require/mail/NotificationMail.php');
 require_once('../require/config/include.php');
 require_once('../require/fichierConf.class.php');
 
 
-$_SESSION['OCS']["readServer"] = dbconnect(SERVER_READ, COMPTE_BASE, PSWD_BASE, DB_NAME);
+$_SESSION['OCS']["readServer"] = dbconnect(SERVER_READ, COMPTE_BASE, PSWD_BASE, DB_NAME, SSL_KEY, SSL_CERT, CA_CERT, SERVER_PORT);
 $mail = new NotificationMail(DEFAULT_LANGUAGE);
 
 $week = array('MON' => 'Monday', 'TUE' => 'Tuesday', 'WED' => 'Wednesday', 'THURS' => 'Thursday', 'FRI' => 'Friday', 'SAT' => 'Saturday', 'SUN' => 'Sunday');
